Struct NonStandardSighashType
pub struct NonStandardSighashType(pub u32);Expand description
This type is consensus valid but an input including it would prevent the transaction from being relayed on today’s Bitcoin network.
Tuple Fields
0: u32Trait Implementations
impl Clone for NonStandardSighashType
impl Clone for NonStandardSighashType
fn clone(&self) -> NonStandardSighashType
fn clone(&self) -> NonStandardSighashType
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Debug for NonStandardSighashType
impl Debug for NonStandardSighashType
impl Display for NonStandardSighashType
impl Display for NonStandardSighashType
impl Error for NonStandardSighashType
impl Error for NonStandardSighashType
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0: use the Display impl or to_string()
impl From<NonStandardSighashType> for Error
impl From<NonStandardSighashType> for Error
fn from(err: NonStandardSighashType) -> Error
fn from(err: NonStandardSighashType) -> Error
Converts to this type from the input type.
impl Hash for NonStandardSighashType
impl Hash for NonStandardSighashType
impl Ord for NonStandardSighashType
impl Ord for NonStandardSighashType
fn cmp(&self, other: &NonStandardSighashType) -> Ordering
fn cmp(&self, other: &NonStandardSighashType) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
impl PartialEq for NonStandardSighashType
impl PartialEq for NonStandardSighashType
impl PartialOrd for NonStandardSighashType
impl PartialOrd for NonStandardSighashType
impl Copy for NonStandardSighashType
impl Eq for NonStandardSighashType
impl StructuralPartialEq for NonStandardSighashType